searchNodes=[{"type":"module","title":"XEts","doc":"A partitioned ETS implementation. This is an Elixir wrapper around the shards library. The Access protocol is implemented. To support the Access protocol, XEts.new/2 returns a struct with the tab field set to the table name. Many of the functions support a struct or a shards tab() as the first argument. Those that take a struct (and the Access protocol callbacks) are chainable as illustrated in the example below. :shard functions that return a value are not chainable, like lookup, select, etc. Examples iex&gt; XEts . new ( :test ) |&gt; ...&gt; XEts . insert ( x : %{ } ) |&gt; ...&gt; put_in ( [ :x , :y ] , 1 ) |&gt; ...&gt; update_in ( [ :x , :y ] , &amp; &amp;1 + 1 ) |&gt; ...&gt; XEts . to_list ( ) [ { :x , %{ y : 2 } } ]","ref":"XEts.html"},{"type":"function","title":"XEts.all/0","doc":"Returns a list of all tables at the node. Equivalent to :ets.all/0.","ref":"XEts.html#all/0"},{"type":"function","title":"XEts.delete/1","doc":"Deletes the entire table. Equivalent to :ets.delete/1.","ref":"XEts.html#delete/1"},{"type":"function","title":"XEts.delete/2","doc":"Delete an item from the table. Examples iex&gt; XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) |&gt; XEts . delete ( :x ) |&gt; XEts . to_list ( ) [ { :y , 2 } ] iex&gt; %{ tab : tab } = XEts . new ( :table1 ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . delete ( tab , :y ) iex&gt; XEts . to_list ( tab ) [ { :x , 1 } ]","ref":"XEts.html#delete/2"},{"type":"function","title":"XEts.delete/3","doc":"Delete a key given metadata.","ref":"XEts.html#delete/3"},{"type":"function","title":"XEts.delete_all_objects/1","doc":"Delete all objects from the table. Examples iex&gt; XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) |&gt; XEts . delete_all_objects ( ) |&gt; XEts . to_list ( ) [ ] iex&gt; %{ tab : tab } = XEts . new ( :table1 ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . delete_all_objects ( tab ) iex&gt; XEts . to_list ( tab ) [ ]","ref":"XEts.html#delete_all_objects/1"},{"type":"function","title":"XEts.delete_all_objects/2","doc":"Delete all objects from the table given metadata.","ref":"XEts.html#delete_all_objects/2"},{"type":"function","title":"XEts.delete_object/2","doc":"Delete an object from the table. Examples iex&gt; XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) |&gt; XEts . delete_object ( { :x , 1 } ) |&gt; XEts . to_list ( ) [ { :y , 2 } ] iex&gt; %{ tab : tab } = XEts . new ( :table1 ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . delete_object ( tab , { :y , 2 } ) iex&gt; XEts . to_list ( tab ) [ { :x , 1 } ]","ref":"XEts.html#delete_object/2"},{"type":"function","title":"XEts.delete_object/3","doc":"Delete an object from the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) iex&gt; XEts . insert ( tab , x : 1 , y : 2 ) iex&gt; meta = :shards_meta . get ( tab . tab ) iex&gt; tab |&gt; XEts . delete_object ( { :x , 1 } , meta ) |&gt; XEts . to_list ( ) [ { :y , 2 } ]","ref":"XEts.html#delete_object/3"},{"type":"function","title":"XEts.fetch/2","doc":"Fetch a value from the table. iex&gt; XEts . new ( :foo ) |&gt; XEts . put ( :k , :v ) |&gt; XEts . fetch ( :k ) { :ok , :v } iex&gt; XEts . new ( :foo , [ ] ) |&gt; XEts . fetch ( :k ) :error","ref":"XEts.html#fetch/2"},{"type":"function","title":"XEts.file2tab/1","doc":"","ref":"XEts.html#file2tab/1"},{"type":"function","title":"XEts.file2tab/2","doc":"","ref":"XEts.html#file2tab/2"},{"type":"function","title":"XEts.first/1","doc":"Equivalent to first(tab, :shards_meta.get(tab)).","ref":"XEts.html#first/1"},{"type":"function","title":"XEts.first/2","doc":"Equivalent to :ets.first/1 . However, the order in which results are returned might be not the same as the original ETS function, since it is a sharded table. See also: :ets.first/1.","ref":"XEts.html#first/2"},{"type":"function","title":"XEts.foldl/3","doc":"Fold left over the table. Examples iex&gt; %{ tab : tab } = XEts . new ( :table ) |&gt; XEts . insert ( y : 1 , x : 2 ) iex&gt; XEts . foldl ( tab , [ ] , fn { k , v } , acc -&gt; [ { k , v * 2 } | acc ] end ) [ x : 4 , y : 2 ]","ref":"XEts.html#foldl/3"},{"type":"function","title":"XEts.foldl/4","doc":"Fold left over the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( y : 1 , x : 2 ) iex&gt; XEts . foldl ( tab , [ ] , XEts . get_meta ( tab ) , fn { k , v } , acc -&gt; [ { k , v * 2 } | acc ] end ) [ x : 4 , y : 2 ] iex&gt; %{ tab : tab } = XEts . new ( :table ) |&gt; XEts . insert ( y : 1 , x : 2 ) iex&gt; XEts . foldl ( tab , [ ] , XEts . get_meta ( tab ) , fn { k , v } , acc -&gt; [ { k , v * 2 } | acc ] end ) [ x : 4 , y : 2 ]","ref":"XEts.html#foldl/4"},{"type":"function","title":"XEts.foldr/3","doc":"Fold right over the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . foldr ( tab , [ ] , fn { k , v } , acc -&gt; [ { k , v * 2 } | acc ] end ) [ x : 2 , y : 4 ]","ref":"XEts.html#foldr/3"},{"type":"function","title":"XEts.foldr/4","doc":"Fold right over the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . foldr ( tab , [ ] , XEts . get_meta ( tab ) , fn { k , v } , acc -&gt; [ { k , v * 2 } | acc ] end ) [ x : 2 , y : 4 ] iex&gt; %{ tab : tab } = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . foldr ( tab , [ ] , XEts . get_meta ( tab ) , fn { k , v } , acc -&gt; [ { k , v * 2 } | acc ] end ) [ x : 2 , y : 4 ]","ref":"XEts.html#foldr/4"},{"type":"function","title":"XEts.get/3","doc":"Get a value from the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . get ( tab , :x ) 1 iex&gt; XEts . get ( tab , :foo ) nil iex&gt; XEts . get ( tab , :foo , :bar ) :bar","ref":"XEts.html#get/3"},{"type":"function","title":"XEts.get_and_update/3","doc":"Get and update an item in the table. iex&gt; tab = XEts . new ( :foo ) |&gt; XEts . put ( :k , 2 ) iex&gt; XEts . get_and_update ( tab , :k , &amp; { &amp;1 , &amp;1 + 1 } ) { 2 , tab }","ref":"XEts.html#get_and_update/3"},{"type":"function","title":"XEts.get_meta/1","doc":"Get the metadata of the table. Examples iex&gt; tab = XEts . new ( :table ) iex&gt; { :meta , pid , _ , _ , fun , false , :infinity , [ ] } = XEts . get_meta ( tab ) iex&gt; is_pid ( pid ) &amp;&amp; is_function ( fun , 2 ) true iex&gt; %{ tab : tab } = XEts . new ( :table ) iex&gt; { :meta , pid , _ , _ , fun , false , :infinity , [ ] } = XEts . get_meta ( tab ) iex&gt; is_pid ( pid ) &amp;&amp; is_function ( fun , 2 ) true","ref":"XEts.html#get_meta/1"},{"type":"function","title":"XEts.i/0","doc":"","ref":"XEts.html#i/0"},{"type":"function","title":"XEts.info/1","doc":"Similar to :ets.info/1 but extra information about the partitioned table is added. Extra Info: {:partitions, pos_integer()} - The number of partitions in the table. {:keyslot_fun, :shards_meta.keyslot_fun()} - Functions used to compute the keyslot. {:parallel, boolean()} - Whether the parallel mode is enabled or not. See also :ets.info/1.","ref":"XEts.html#info/1"},{"type":"function","title":"XEts.info/2","doc":"Equivalent to :ets.info/2 . See the added items by XEts.info/1 . See also: :ets.info/2.","ref":"XEts.html#info/2"},{"type":"function","title":"XEts.insert/2","doc":"Insert an item into the table. Examples iex&gt; XEts . new ( :table ) |&gt; XEts . insert ( { :x , 5 } ) |&gt; XEts . to_list ( ) [ { :x , 5 } ] iex&gt; tab = XEts . new ( :table ) |&gt; Map . get ( :tab ) iex&gt; XEts . insert ( tab , { :x , 5 } ) iex&gt; XEts . to_list ( tab ) [ { :x , 5 } ]","ref":"XEts.html#insert/2"},{"type":"function","title":"XEts.insert/3","doc":"Insert an item into the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) iex&gt; tab |&gt; XEts . insert ( { :x , 5 } , XEts . get_meta ( tab ) ) |&gt; XEts . to_list ( ) [ { :x , 5 } ]","ref":"XEts.html#insert/3"},{"type":"function","title":"XEts.insert_new/2","doc":"Insert a new item into the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . insert_new ( tab , { :x , 3 } ) |&gt; XEts . to_list ( ) [ { :y , 2 } , { :x , 1 } ]","ref":"XEts.html#insert_new/2"},{"type":"function","title":"XEts.insert_new/3","doc":"Insert a new item into the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . insert_new ( tab , { :x , 3 } , XEts . get_meta ( tab ) ) |&gt; XEts . to_list ( ) [ { :y , 2 } , { :x , 1 } ]","ref":"XEts.html#insert_new/3"},{"type":"function","title":"XEts.is_compiled_ms/1","doc":"Check if an item is a compiled match spec. Examples iex&gt; XEts . is_compiled_ms ( { :x , 1 } ) false","ref":"XEts.html#is_compiled_ms/1"},{"type":"function","title":"XEts.last/1","doc":"Get the last item in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . last ( tab ) :y","ref":"XEts.html#last/1"},{"type":"function","title":"XEts.lookup/2","doc":"Lookup an item in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . lookup ( tab , :x ) [ x : 1 ] iex&gt; %{ tab : tab } = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . lookup ( tab , :y ) [ y : 2 ]","ref":"XEts.html#lookup/2"},{"type":"function","title":"XEts.lookup/3","doc":"Lookup an item in the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . lookup ( tab , :x , XEts . get_meta ( tab ) ) [ x : 1 ]","ref":"XEts.html#lookup/3"},{"type":"function","title":"XEts.lookup_element/3","doc":"Lookup an element in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . lookup_element ( tab , :x , 1 ) :x iex&gt; XEts . lookup_element ( tab , :x , 2 ) 1 iex&gt; %{ tab : tab } = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . lookup_element ( tab , :y , 2 ) 2","ref":"XEts.html#lookup_element/3"},{"type":"function","title":"XEts.lookup_element/4","doc":"Lookup an element in the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . lookup_element ( tab , :x , 1 , XEts . get_meta ( tab ) ) :x iex&gt; XEts . lookup_element ( tab , :x , 2 , XEts . get_meta ( tab ) ) 1","ref":"XEts.html#lookup_element/4"},{"type":"function","title":"XEts.match/1","doc":"","ref":"XEts.html#match/1"},{"type":"function","title":"XEts.match/2","doc":"Match an item in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . match ( tab , :&quot;$1&quot; ) [ [ y : 2 ] , [ x : 1 ] ] iex&gt; %{ tab : tab } = XEts . new ( :table ) |&gt; XEts . insert ( { { :item , 1 } , 2 } ) iex&gt; XEts . match ( tab , { { :item , :&quot;$1&quot; } , :&quot;$2&quot; } ) [ [ 1 , 2 ] ]","ref":"XEts.html#match/2"},{"type":"function","title":"XEts.match/3","doc":"Match an item in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . match ( tab , :&quot;$1&quot; , XEts . get_meta ( tab ) ) [ [ y : 2 ] , [ x : 1 ] ] iex&gt; %{ tab : tab } = XEts . new ( :table1 ) |&gt; XEts . insert ( x : 1 , y : 2 , z : 3 ) iex&gt; XEts . match ( tab , { :&quot;$1&quot; , :&quot;$2&quot; } , 2 ) |&gt; elem ( 0 ) [ [ :y , 2 ] , [ :z , 3 ] ]","ref":"XEts.html#match/3"},{"type":"function","title":"XEts.match/4","doc":"Match an item in the table given metadata and limit. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . match ( tab , :&quot;$1&quot; , 2 , XEts . get_meta ( tab ) ) |&gt; elem ( 0 ) [ [ x : 1 ] , [ y : 2 ] ] iex&gt; %{ tab : tab } = XEts . new ( :table1 ) |&gt; XEts . insert ( x : 1 , y : 2 , z : 3 ) iex&gt; XEts . match ( tab , { :&quot;$1&quot; , :&quot;$2&quot; } , 2 , XEts . get_meta ( tab ) ) |&gt; elem ( 0 ) [ [ :y , 2 ] , [ :z , 3 ] ]","ref":"XEts.html#match/4"},{"type":"function","title":"XEts.match_delete/2","doc":"Match an item in the table and delete it. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; tab |&gt; XEts . match_delete ( { :x , :_ } ) |&gt; XEts . to_list ( ) [ { :y , 2 } ] iex&gt; tab |&gt; XEts . match_delete ( { :_ , 2 } ) |&gt; XEts . to_list ( ) [ ]","ref":"XEts.html#match_delete/2"},{"type":"function","title":"XEts.match_delete/3","doc":"Match an item in the table and delete it given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; tab |&gt; XEts . match_delete ( { :x , :_ } , XEts . get_meta ( tab ) ) |&gt; XEts . to_list ( ) [ { :y , 2 } ]","ref":"XEts.html#match_delete/3"},{"type":"function","title":"XEts.match_object/2","doc":"Match an item in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; tab |&gt; XEts . match_object ( { :x , :_ } ) [ { :x , 1 } ] iex&gt; tab |&gt; XEts . match_object ( { :_ , 2 } ) [ { :y , 2 } ]","ref":"XEts.html#match_object/2"},{"type":"function","title":"XEts.match_object/3","doc":"Match an item in the table given limit or metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 , z : 3 ) iex&gt; tab |&gt; XEts . match_object ( { :x , :_ } , XEts . get_meta ( tab ) ) [ { :x , 1 } ] iex&gt; tab |&gt; XEts . match_object ( :_ , 2 ) |&gt; elem ( 0 ) [ { :y , 2 } , { :z , 3 } ]","ref":"XEts.html#match_object/3"},{"type":"function","title":"XEts.match_object/4","doc":"Match an item in the table given limit and metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 1 , z : 1 ) iex&gt; tab |&gt; XEts . match_object ( { :_ , 1 } , 2 , XEts . get_meta ( tab ) ) |&gt; elem ( 0 ) [ { :y , 1 } , { :z , 1 } ]","ref":"XEts.html#match_object/4"},{"type":"function","title":"XEts.match_spec_compile/1","doc":"","ref":"XEts.html#match_spec_compile/1"},{"type":"function","title":"XEts.match_spec_run/2","doc":"","ref":"XEts.html#match_spec_run/2"},{"type":"function","title":"XEts.member?/2","doc":"Check if an item is a member of the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . member? ( tab , :x ) true iex&gt; XEts . member? ( tab , :z ) false","ref":"XEts.html#member?/2"},{"type":"function","title":"XEts.member?/3","doc":"Check if an item is a member of the table given metadata. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; XEts . member? ( tab , :x , XEts . get_meta ( tab ) ) true iex&gt; XEts . member? ( tab , :z , XEts . get_meta ( tab ) ) false","ref":"XEts.html#member?/3"},{"type":"function","title":"XEts.new/2","doc":"Create a new table. Examples iex&gt; %{ tab : tab , keypos : 1 } = XEts . new ( :table ) iex&gt; is_reference ( tab ) true","ref":"XEts.html#new/2"},{"type":"function","title":"XEts.next/3","doc":"Get the next item in the table. Examples iex&gt; tab = XEts . new ( :table ) |&gt; XEts . insert ( x : 1 , y : 2 ) iex&gt; tab |&gt; XEts . next ( :x , XEts . get_meta ( tab ) ) :&quot;$end_of_table&quot;","ref":"XEts.html#next/3"},{"type":"function","title":"XEts.partition_owners/1","doc":"Returns the partition PIDs associated with the given table TabOrPid .","ref":"XEts.html#partition_owners/1"},{"type":"function","title":"XEts.pop/3","doc":"Pop an item from the table. iex&gt; tab = XEts.KV . new ( :foo , [ ] ) iex&gt; tab |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . pop ( :k ) { :v , tab }","ref":"XEts.html#pop/3"},{"type":"function","title":"XEts.prev/2","doc":"Returns the previous item in the table. Equivalent to :ets.next/2 However, the order in which results are returned might not be the same as the original ETS function, since it's a sharded table. See also: :ets.pray/2.","ref":"XEts.html#prev/2"},{"type":"function","title":"XEts.put/2","doc":"Put an item or items into the table. Examples iex&gt; XEts . new ( :table ) |&gt; XEts . put ( x : 1 , y : 2 ) |&gt; XEts . to_list ( ) [ y : 2 , x : 1 ]","ref":"XEts.html#put/2"},{"type":"function","title":"XEts.put/3","doc":"Put an item into the table. Examples iex&gt; XEts . new ( :table ) |&gt; XEts . put ( :x , 1 ) |&gt; XEts . to_list ( ) [ x : 1 ]","ref":"XEts.html#put/3"},{"type":"function","title":"XEts.put_meta/3","doc":"Put metadata into the table. Wrapper for :shards_meta.put/3 .","ref":"XEts.html#put_meta/3"},{"type":"function","title":"XEts.rename/2","doc":"Equivalent to rename(tab, name, :shards_meta.get(tab))","ref":"XEts.html#rename/2"},{"type":"function","title":"XEts.rename/3","doc":"Equivalent to :ets.rename/2 . Renames the table name and all its associated shard tables. If something unexpected occurs during the process, an exception will be raised. See also: :ets.rename/2.","ref":"XEts.html#rename/3"},{"type":"function","title":"XEts.safe_fixtable/2","doc":"Equivalent to :ets.safe_fixtable/2 .","ref":"XEts.html#safe_fixtable/2"},{"type":"function","title":"XEts.select/1","doc":"Equivalent to :ets.select/1 . The order in which results are returned might be not the same as the original ETS function. See also: ets:select/1.","ref":"XEts.html#select/1"},{"type":"function","title":"XEts.select/2","doc":"Equivalent to :ets.select/2 . See also: ets:select/2.","ref":"XEts.html#select/2"},{"type":"function","title":"XEts.select/3","doc":"Select items from the table given a match spec and limit or metadata. If 3rd argument is pos_integer() this function behaves like ets:select/3, otherwise, the 3rd argument is assumed as shards_meta:t() and it behaves like ets:select/2. The order in which results are returned might be not the same as the original ETS function. See also: :ets.select/3.","ref":"XEts.html#select/3"},{"type":"function","title":"XEts.select/4","doc":"Select items from the table given a match spec and limit or metadata. If 3rd argument is pos_integer() this function behaves like ets:select/3, otherwise, the 3rd argument is assumed as shards_meta:t() and it behaves like ets:select/2. The order in which results are returned might be not the same as the original ETS function. See also: :ets.select/3.","ref":"XEts.html#select/4"},{"type":"function","title":"XEts.select_count/2","doc":"Equivalent to select_count(tab, match_spec, :shards_meta.get(tab)).","ref":"XEts.html#select_count/2"},{"type":"function","title":"XEts.select_count/3","doc":"Equivalent to :ets.select_count/2 . See also: :ets.select_count/2.","ref":"XEts.html#select_count/3"},{"type":"function","title":"XEts.select_delete/2","doc":"Equivalent to select_delete(tab, match_spec, :shards_meta.get(tab)).","ref":"XEts.html#select_delete/2"},{"type":"function","title":"XEts.select_delete/3","doc":"Equivalent to :ets.select_delete/2 . See also: :ets.select_delete/2.","ref":"XEts.html#select_delete/3"},{"type":"function","title":"XEts.select_replace/2","doc":"Equivalent to select_replace(tab, match_spec, :shards_meta.get(tab)).","ref":"XEts.html#select_replace/2"},{"type":"function","title":"XEts.select_replace/3","doc":"Equivalent to :ets.select_replace/2 . See also: :ets.select_replace/2.","ref":"XEts.html#select_replace/3"},{"type":"function","title":"XEts.select_reverse/1","doc":"Equivalent to :ets.select_reverse/1 . The order in which results are returned might be not the same as the original ETS function. See also: :ets.select_reverse/1.","ref":"XEts.html#select_reverse/1"},{"type":"function","title":"XEts.select_reverse/2","doc":"Equivalent to select_reverse(tab, match_spec, :shards_meta.get(tab)).","ref":"XEts.html#select_reverse/2"},{"type":"function","title":"XEts.select_reverse/3","doc":"Select items in reverse order given a match spec and limit or metadata. If 3rd argument is pos_integer() this function behaves like ets:select_reverse/3, otherwise, the 3rd argument is assumed as shards_meta:t() and it behaves like :ets.select_reverse/2. The order in which results are returned might be not the same as the original ETS function. See also: :ets.select_reverse/3.","ref":"XEts.html#select_reverse/3"},{"type":"function","title":"XEts.select_reverse/4","doc":"Equivalent to :ets.select_reverse/3. The order in which results are returned might be not the same as the original ETS function. See also: :ets.select_reverse/3.","ref":"XEts.html#select_reverse/4"},{"type":"function","title":"XEts.setopts/2","doc":"Equivalent to setopts(tab, opts, :shards_meta.get(tab)).","ref":"XEts.html#setopts/2"},{"type":"function","title":"XEts.setopts/3","doc":"Equivalent to :ets.setopts/2 . Returns true if the function was applied successfully on each partition, otherwise, false is returned. See also: :ets.setopts/2.","ref":"XEts.html#setopts/3"},{"type":"function","title":"XEts.size/1","doc":"Get the size of the table.","ref":"XEts.html#size/1"},{"type":"function","title":"XEts.tab2file/2","doc":"Equivalent to tab2file(tab, filename, []).","ref":"XEts.html#tab2file/2"},{"type":"function","title":"XEts.tab2file/3","doc":"Equivalent to :ets.tab2file/3 . This function generates one file per partition using :ets.tab2file/3, and also generates a master file with the given Filename that holds the information of the created partition files so that they can be recovered by calling :ets.file2tab/1,2. See also: :ets.tab2file/3.","ref":"XEts.html#tab2file/3"},{"type":"function","title":"XEts.tab2list/1","doc":"Equivalent to tab2list(tab, :shards_meta.get(tab)).","ref":"XEts.html#tab2list/1"},{"type":"function","title":"XEts.tab2list/2","doc":"Equivalent to :ets.tab2list/1 . See also: :ets.tab2list/1.","ref":"XEts.html#tab2list/2"},{"type":"function","title":"XEts.tabfile_info/1","doc":"Equivalent to :ets.tabfile_info/1 . Adds extra information about the partitions. See also: :shards.tabfile_info/1.","ref":"XEts.html#tabfile_info/1"},{"type":"function","title":"XEts.table/1","doc":"Equivalent to table(tab, []).","ref":"XEts.html#table/1"},{"type":"function","title":"XEts.table/2","doc":"Equivalent to table(tab, options, :shards_meta.get(tab)).","ref":"XEts.html#table/2"},{"type":"function","title":"XEts.table/3","doc":"Similar to :ets.table/2 , but it returns a list of :qlc.query_handle(); one per partition. See also: :ets.table/2.","ref":"XEts.html#table/3"},{"type":"function","title":"XEts.table_meta/1","doc":"Returns the metadata associated with the given table.","ref":"XEts.html#table_meta/1"},{"type":"function","title":"XEts.take/2","doc":"Equivalent to take(tab, key, :shards_meta.get(tab)).","ref":"XEts.html#take/2"},{"type":"function","title":"XEts.take/3","doc":"Equivalent to :ets.take/2 . See also: :ets.take/2.","ref":"XEts.html#take/3"},{"type":"function","title":"XEts.test_ms/2","doc":"Equivalent to :ets.test_ms/2 .","ref":"XEts.html#test_ms/2"},{"type":"function","title":"XEts.to_list/1","doc":"Convert a table to a list of tuples. See also: :ets.tab2list/1.","ref":"XEts.html#to_list/1"},{"type":"function","title":"XEts.update_counter/3","doc":"Equivalent to update_counter(tab, key, update_op, :shards_meta.get(tab)). Examples iex&gt; %{ tab : tab } = :test |&gt; XEts . new ( ) |&gt; XEts . insert ( { 10 , 10 , 4 , &quot;description&quot; } ) iex&gt; XEts . update_counter ( tab , 10 , { 3 , 1 } ) 5 iex&gt; XEts . lookup ( tab , 10 ) [ { 10 , 10 , 5 , &quot;description&quot; } ]","ref":"XEts.html#update_counter/3"},{"type":"function","title":"XEts.update_counter/4","doc":"Equivalent to update_counter(tab, key, update_op, default_or_meta). Examples iex&gt; %{ tab : tab } = :test |&gt; XEts . new ( ) iex&gt; XEts . update_counter ( tab , 10 , { 3 , 1 } , { 10 , 10 , 4 , &quot;description&quot; } ) 5 iex&gt; XEts . lookup ( tab , 10 ) [ { 10 , 10 , 5 , &quot;description&quot; } ]","ref":"XEts.html#update_counter/4"},{"type":"function","title":"XEts.update_counter/5","doc":"Equivalent to update_counter(tab, key, update_op, default, meta). Examples iex&gt; %{ tab : tab } = :test |&gt; XEts . new ( ) |&gt; XEts . insert ( x : 0 , y : 1 ) iex&gt; meta = XEts . get_meta ( tab ) iex&gt; XEts . update_counter ( tab , :x , { 2 , 3 } , { :x , 0 } , meta ) 3 iex&gt; XEts . update_counter ( tab , :y , { 2 , 3 } , { :y , 0 } , meta ) 4 iex&gt; XEts . update_counter ( tab , :z , { 2 , - 1 } , { :z , 5 } , meta ) 4 iex&gt; XEts . to_list ( tab ) |&gt; Enum . sort ( ) [ x : 3 , y : 4 , z : 4 ]","ref":"XEts.html#update_counter/5"},{"type":"function","title":"XEts.update_element/3","doc":"Equivalent to update_element(tab, key, element_spec, :shards_meta.get(tab)). Examples iex&gt; %{ tab : tab } = :test |&gt; XEts . new ( ) |&gt; XEts . insert ( x : 2 , y : 4 ) iex&gt; XEts . update_element ( tab , :x , { 2 , 10 } ) true iex&gt; XEts . lookup ( tab , :x ) [ { :x , 10 } ]","ref":"XEts.html#update_element/3"},{"type":"function","title":"XEts.update_element/4","doc":"Equivalent to :ets.update_element/3 . See also: :ets.update_element/3.","ref":"XEts.html#update_element/4"},{"type":"function","title":"XEts.whereis/1","doc":"Equivalent to :ets.whereis/1 . See also: :ets.whereis/1. Examples iex&gt; XEts . new ( :test , [ :named_table ] ) iex&gt; XEts . whereis ( :test ) |&gt; is_reference ( ) true iex&gt; XEts . whereis ( :test2 ) :undefined","ref":"XEts.html#whereis/1"},{"type":"type","title":"XEts.continuation/0","doc":"","ref":"XEts.html#t:continuation/0"},{"type":"type","title":"XEts.element_spec/0","doc":"","ref":"XEts.html#t:element_spec/0"},{"type":"type","title":"XEts.filename/0","doc":"","ref":"XEts.html#t:filename/0"},{"type":"type","title":"XEts.info_item/0","doc":"","ref":"XEts.html#t:info_item/0"},{"type":"type","title":"XEts.info_tuple/0","doc":"","ref":"XEts.html#t:info_tuple/0"},{"type":"type","title":"XEts.limit/0","doc":"","ref":"XEts.html#t:limit/0"},{"type":"type","title":"XEts.limit_or_meta/0","doc":"","ref":"XEts.html#t:limit_or_meta/0"},{"type":"type","title":"XEts.match_spec/0","doc":"","ref":"XEts.html#t:match_spec/0"},{"type":"type","title":"XEts.meta/0","doc":"","ref":"XEts.html#t:meta/0"},{"type":"type","title":"XEts.n_objects/0","doc":"","ref":"XEts.html#t:n_objects/0"},{"type":"type","title":"XEts.opt/0","doc":"","ref":"XEts.html#t:opt/0"},{"type":"type","title":"XEts.option/0","doc":"","ref":"XEts.html#t:option/0"},{"type":"type","title":"XEts.options/0","doc":"","ref":"XEts.html#t:options/0"},{"type":"type","title":"XEts.opts/0","doc":"","ref":"XEts.html#t:opts/0"},{"type":"type","title":"XEts.t/0","doc":"","ref":"XEts.html#t:t/0"},{"type":"type","title":"XEts.tab/0","doc":"","ref":"XEts.html#t:tab/0"},{"type":"type","title":"XEts.tabinfo_item/0","doc":"","ref":"XEts.html#t:tabinfo_item/0"},{"type":"type","title":"XEts.traversal_method/0","doc":"","ref":"XEts.html#t:traversal_method/0"},{"type":"module","title":"XEts.KV","doc":"A module for working with ETS tables. This module is a wrapper around the :shards module which is provides a high level of concurrency and scalability without the need for locks. Supports the Access protocol for getting and setting values.","ref":"XEts.KV.html"},{"type":"function","title":"XEts.KV.delete/2","doc":"Delete an item from the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . delete ( :k ) |&gt; XEts.KV . to_list ( ) [ ]","ref":"XEts.KV.html#delete/2"},{"type":"function","title":"XEts.KV.delete_all/1","doc":"Delete all items from the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . delete_all ( ) |&gt; XEts.KV . to_list ( ) [ ]","ref":"XEts.KV.html#delete_all/1"},{"type":"function","title":"XEts.KV.fetch/2","doc":"Get an item from the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . fetch ( :k ) { :ok , :v } iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . fetch ( :k ) :error","ref":"XEts.KV.html#fetch/2"},{"type":"function","title":"XEts.KV.get/3","doc":"Get an item from the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . get ( :k ) :v","ref":"XEts.KV.html#get/3"},{"type":"function","title":"XEts.KV.get_and_update/3","doc":"Get and update an item in the table. iex&gt; tab = XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , 2 ) iex&gt; XEts.KV . get_and_update ( tab , :k , &amp; { &amp;1 , &amp;1 + 1 } ) { 2 , tab }","ref":"XEts.KV.html#get_and_update/3"},{"type":"function","title":"XEts.KV.info/1","doc":"Get information about the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . info ( ) |&gt; length ( ) 18","ref":"XEts.KV.html#info/1"},{"type":"function","title":"XEts.KV.info/2","doc":"Get information about a key in the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . info ( :name ) :foo","ref":"XEts.KV.html#info/2"},{"type":"function","title":"XEts.KV.match/4","doc":"Get an item from the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . get ( :k ) :v","ref":"XEts.KV.html#match/4"},{"type":"function","title":"XEts.KV.match_delete/3","doc":"Delete an item from the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . match_delete ( :&quot;$1&quot; ) |&gt; XEts.KV . to_list ( ) [ ]","ref":"XEts.KV.html#match_delete/3"},{"type":"function","title":"XEts.KV.member?/2","doc":"Test if key is a member. iex&gt; :foo |&gt; XEts.KV . new ( [ ] ) |&gt; XEts.KV . put ( :x , nil ) |&gt; XEts.KV . member? ( :x ) true iex&gt; :bar |&gt; XEts.KV . new ( [ ] ) |&gt; XEts.KV . member? ( :x ) false","ref":"XEts.KV.html#member?/2"},{"type":"function","title":"XEts.KV.new/2","doc":"","ref":"XEts.KV.html#new/2"},{"type":"function","title":"XEts.KV.pop/3","doc":"Pop an item from the table. iex&gt; tab = XEts.KV . new ( :foo , [ ] ) iex&gt; tab |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . pop ( :k ) { :v , tab }","ref":"XEts.KV.html#pop/3"},{"type":"function","title":"XEts.KV.put/2","doc":"Put one or more items into the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( { :k , :v } ) |&gt; XEts.KV . to_list ( ) [ { :k , :v } ] iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( k : :v , k2 : :v2 ) |&gt; XEts.KV . to_list ( ) [ { :k , :v } , { :k2 , :v2 } ]","ref":"XEts.KV.html#put/2"},{"type":"function","title":"XEts.KV.put/3","doc":"Put an item into the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . to_list ( ) [ { :k , :v } ]","ref":"XEts.KV.html#put/3"},{"type":"function","title":"XEts.KV.put_new/2","doc":"Put one or more new items into the table. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; ...&gt; XEts.KV . put ( { :k , :v } ) |&gt; ...&gt; XEts.KV . put_new ( :k , :v2 ) |&gt; ...&gt; XEts.KV . to_list ( ) [ { :k , :v } ] iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; ...&gt; XEts.KV . put ( k : :v , k2 : :v2 ) |&gt; ...&gt; XEts.KV . put_new ( [ k : :v3 , k2 : :vv ] ) |&gt; ...&gt; XEts.KV . to_list ( ) [ { :k , :v } , { :k2 , :v2 } ]","ref":"XEts.KV.html#put_new/2"},{"type":"function","title":"XEts.KV.put_new/3","doc":"Put an item into the table if it doesn't exist. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put_new ( :k , :v ) |&gt; XEts.KV . to_list ( ) [ { :k , :v } ]","ref":"XEts.KV.html#put_new/3"},{"type":"function","title":"XEts.KV.to_list/1","doc":"Convert the table to a list. iex&gt; XEts.KV . new ( :foo , [ ] ) |&gt; XEts.KV . put ( :k , :v ) |&gt; XEts.KV . to_list ( ) [ { :k , :v } ]","ref":"XEts.KV.html#to_list/1"},{"type":"type","title":"XEts.KV.t/0","doc":"","ref":"XEts.KV.html#t:t/0"},{"type":"extras","title":"XEts","doc":"XEts A partitioned ETS implementation. This is a wrapper around the shards library as well as a key-value store implementation. See XEts.KV for the key-value store implementation.","ref":"readme.html"},{"type":"extras","title":"XEts - Installation","doc":"If available in Hex , the package can be installed by adding x_ets to your list of dependencies in mix.exs : def deps do [ { :x_ets , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation"},{"type":"extras","title":"XEts - Usage","doc":"XEts iex&gt; tab = XEts . new ( :table_name , [ :named_table ] ) iex&gt; tab |&gt; XEts . insert ( x : 1 , y : %{ } ) |&gt; put_in ( [ :y , :z ] , 1 ) |&gt; ...&gt; update_in ( [ :y , :z ] , &amp; &amp;1 + 1 ) |&gt; XEts . to_list ( ) [ x : 1 , y : %{ z : 2 } ] XEts.KV iex&gt; tab = XEts.KV . new ( :table_name , [ ] ) iex&gt; tab |&gt; XEts.KV . put ( :x , 1 ) |&gt; XEts.KV . put ( :y , %{ z : 1 } ) |&gt; XEts.KV . get ( :x ) 1 iex&gt; tab |&gt; update_in ( [ :y , :z ] , &amp; &amp;1 + 1 ) |&gt; get_in ( [ :y , :z ] ) 2 Documentation can be generated with ExDoc and published on HexDocs . Once published, the docs can be found at https://hexdocs.pm/x_ets .","ref":"readme.html#usage"},{"type":"extras","title":"LICENSE","doc":"The MIT License (MIT) Copyright (c) 2025 E-MetroTel Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}]